# Author: Colin D Bennett <colin@gibibit.com>
# Revision: 2
# Date: 2011-08-10
#
# Footprint for mating with Tag-Connect TC2030-MCP-NL spring-pin connector.
#
# Manufacturer: Tag-Connect, LLC
# Part number: TC2030-MCP-NL
# Contact count: 6
# Retaining latch: No
# Plated alignment holes for solder retention: Yes
#
# Note 1: This footprint is for the no-legs version of the connector.
#
# Note 2: This variant of the footprint uses plated through-holes for the
# alignment pin holes to allow soldering the alignment pins for retention.
#
# References
#
# [1] Tag-Connect TC2030-MCP-NL footprint.
#     <http://tag-connect.com/Materials/TC2030-MCP-NL%20PCB%20Footprint.pdf>

Element["" "Tag-Connect_TC2030-MCP-NL_PlatedHoles" "J0" "" 47000 59000 16329 -3269 0 100 ""]
(

    # ==================================================================
    # Contact pads
    # ==================================================================

    # ------------------------------------------------------------------
    # Pad[    rX1       rY1       rX2       rY2  Thickn   Clr    Msk  Nm  Nr SFlags]
    # ------------------------------------------------------------------

    Pad[-50.01mil  25.00mil -49.99mil  25.00mil   31mil 50mil  40mil  "1" "1" "nopaste"]
    Pad[ -0.01mil  25.00mil   0.01mil  25.00mil   31mil 50mil  40mil  "3" "3" "nopaste"]
    Pad[ 50.01mil  25.00mil  49.99mil  25.00mil   31mil 50mil  40mil  "5" "5" "nopaste"]
    Pad[-50.01mil -25.00mil -49.99mil -25.00mil   31mil 50mil  40mil  "2" "2" "nopaste"]
    Pad[ -0.01mil -25.00mil   0.01mil -25.00mil   31mil 50mil  40mil  "4" "4" "nopaste"]
    Pad[ 50.01mil -25.00mil  49.99mil -25.00mil   31mil 50mil  40mil  "6" "6" "nopaste"]


    # ==================================================================
    # Alignment Holes (Plated)
    # ==================================================================
    #
    # The alignment holes have a pad on the back side of the board to provide a
    # larger copper annulus for soldering.
    #
    # Copper: outer diameter of copper annulus
    # Clr: add to thickness to get clearance diameter
    # Mask: diameter of solder mask opening
    # Drill: diameter of drill
	# Pin[    X        Y  Copper   Clr  Mask  Drill  Nm  Nr SFlags ]
    #
    # Plated through-holes with 8 mil annulus (front side).
	Pin[-100mil   0.0mil  55mil  32mil 59mil  39mil  ""  "" ""]
	Pin[ 100mil -40.0mil  55mil  32mil 59mil  39mil  ""  "" ""]
	Pin[ 100mil  40.0mil  55mil  32mil 59mil  39mil  ""  "" ""]
    # Circular pads on bottom side to create larger annulus on back side for
    # which to solder alignment pins.
    # Annulus on back side: (67 mil - 39 mil drill) / 2 = 14 mil
    Pad[-100.01mil   0.0mil -99.99mil    0.0mil   67mil 32mil  73mil   "" "" "onsolder,nopaste"]
    Pad[ 100.01mil -40.0mil  99.99mil  -40.0mil   67mil 32mil  73mil   "" "" "onsolder,nopaste"]
    Pad[ 100.01mil  40.0mil  99.99mil   40.0mil   67mil 32mil  73mil   "" "" "onsolder,nopaste"]

    # ==================================================================
    # Silk screen
    # ==================================================================

    #
    # Keep-out for parts with height less than 164 mil.
    # 285 mil X 150 mil
    #

    # Left
    ElementLine [ -142.5mil  -75.0mil -142.5mil   75.0mil  10mil ]
    # Right
    ElementLine [  142.5mil  -75.0mil  142.5mil   75.0mil  10mil ]
    # Top
    ElementLine [ -142.5mil  -75.0mil  142.5mil  -75.0mil  10mil ]
    # Bottom
    ElementLine [ -142.5mil   75.0mil  142.5mil   75.0mil  10mil ]

    )
# vim: set et nosmarttab smartindent ts=4 sts=4 sw=4 fileencoding=utf-8:
