# Author: Colin D Bennett <colin@gibibit.com>
# Revision: 2
# Date: 2011-08-10
#
# Footprint for mating with Tag-Connect TC2030-MCP spring-pin connector.
#
# Manufacturer: Tag-Connect, LLC
# Part number: TC2030-MCP
# Contact count: 6
# Retaining latch: Yes
# Plated alignment holes for solder retention: No
#
# Note 1: This footprint is for the version of the connector with retaining
# latch legs.
#
# Note 2: This variant of the footprint uses non-plated through-holes for the
# alignment pin holes, as recommended by the TC2030-MCP-FP footprint drawing
# (revised 12/2/10) supplied by Tag-Connect.
#
# References
#
# [1] Tag-Connect TC2030-MCP footprint.
#     <http://tag-connect.com/Materials/TC2030-MCP%20PCB%20Footprint.pdf>

Element["" "Tag-Connect_TC2030-MCP" "J0" "" 47000 59000 16329 -3269 0 100 ""]
(

    # ==================================================================
    # Contact pads
    # ==================================================================

    # ------------------------------------------------------------------
    # Pad[    rX1       rY1       rX2       rY2  Thickn   Clr    Msk  Nm  Nr SFlags]
    # ------------------------------------------------------------------

    Pad[-50.01mil  25.00mil -49.99mil  25.00mil   31mil 50mil  40mil  "1" "1" "nopaste"]
    Pad[ -0.01mil  25.00mil   0.01mil  25.00mil   31mil 50mil  40mil  "3" "3" "nopaste"]
    Pad[ 50.01mil  25.00mil  49.99mil  25.00mil   31mil 50mil  40mil  "5" "5" "nopaste"]
    Pad[-50.01mil -25.00mil -49.99mil -25.00mil   31mil 50mil  40mil  "2" "2" "nopaste"]
    Pad[ -0.01mil -25.00mil   0.01mil -25.00mil   31mil 50mil  40mil  "4" "4" "nopaste"]
    Pad[ 50.01mil -25.00mil  49.99mil -25.00mil   31mil 50mil  40mil  "6" "6" "nopaste"]


    # ==================================================================
    # Alignment Holes (Unplated)
    # ==================================================================
    #
    # The alignment holes are unplated.
    #
    # Copper: outer diameter of copper annulus
    # Clr: add to thickness to get clearance diameter
    # Mask: diameter of solder mask opening
    # Drill: diameter of drill
	# Pin[    X        Y  Copper   Clr  Mask  Drill  Nm  Nr SFlags ]
	Pin[-100mil   0.0mil   0mil  32mil 47mil  39mil  ""  "" "hole"]
	Pin[ 100mil -40.0mil   0mil  32mil 47mil  39mil  ""  "" "hole"]
	Pin[ 100mil  40.0mil   0mil  32mil 47mil  39mil  ""  "" "hole"]


    # ==================================================================
    # Leg latch holes
    # ==================================================================
	Pin[-100mil  100mil   0mil  32mil 99.5mil 93.5mil ""  "" "hole"]
	Pin[-100mil -100mil   0mil  32mil 99.5mil 93.5mil ""  "" "hole"]
	Pin[  25mil  100mil   0mil  32mil 99.5mil 93.5mil ""  "" "hole"]
	Pin[  25mil -100mil   0mil  32mil 99.5mil 93.5mil ""  "" "hole"]


    # ==================================================================
    # Silk screen
    # ==================================================================

    #
    # Keep-out for parts with height less than 164 mil.
    # 285 mil X 150 mil
    #

    # Left
    ElementLine [ -142.5mil  -75.0mil -142.5mil   75.0mil  10mil ]
    # Right
    ElementLine [  142.5mil  -75.0mil  142.5mil   75.0mil  10mil ]
    # Top
    ElementLine [ -142.5mil  -75.0mil  142.5mil  -75.0mil  10mil ]
    # Bottom
    ElementLine [ -142.5mil   75.0mil  142.5mil   75.0mil  10mil ]



    # ------------------------------------------------------------------
    # Keep-out area for with-legs version, bottom side of board.
    # ------------------------------------------------------------------

    # --- Left ---
    # Left leg latch holes have X=-100mil, Y=±100mil and D=93.5mil
    # X direction: Put the border 4 mil outside the hole.
    #              -100mil - (93.5mil)/2 - 4mil + 10mil/2= -145.75
    # Y direction: Put the border 46 mil outside the hole
    #              for latch clearance on bottom of board.
    #              (set the edge of 10mil border for clearance)
    #              100mil + (93.5mil)/2 + 46mil - 10mil/2 = 187.75
    # --- Right ---
    # Right leg latch holes have X=25, Y=±100mil and D=93.5mil
    # X direction: Put the border 4 mil outside the hole.
    #              25mil + (93.5mil)/2 + 4mil - 10mil/2= 70.75
    # Y direction: Put the border 46 mil outside the hole
    #              for latch clearance on bottom of board.
    #              (set the edge of 10mil border for clearance)
    #              100mil + (93.5mil)/2 + 46mil - 10mil/2 = 187.75

    # --- Dotted silk lines ---
    # Generate with:
    #   cat <<END | python
    #   from pcb_dashed_line import *
    #
    #   def dline(a, b):
    #       dashed_line(a, b, linewidth=8, step=20)
    #
    #   comment("{{{ BEGIN GENERATED CONTENT")
    #   comment("Top")
    #   dline([-145.75, -187.75], [78.75, -187.75])
    #   comment("Bottom")
    #   dline([-145.75,  187.75], [78.75,  187.75])
    #   comment("Left (top segment)")
    #   dline([-145.75, -187.75], [-145.75, -75.0])
    #   comment("Left (bottom segment)")
    #   dline([-145.75,  187.75], [-145.75,  75.0])
    #   comment("Right (top segment)")
    #   dline([70.75, -187.75], [70.75, -75.0])
    #   comment("Right (bottom segment)")
    #   dline([70.75, 187.75], [70.75, 75.0])
    #   comment("}}} END GENERATED CONTENT")
    #   END

    # {{{ BEGIN GENERATED CONTENT
    # Top
    ElementLine [ -146.25mil -188.25mil -145.25mil -187.25mil 8mil ]
    ElementLine [ -126.25mil -188.25mil -125.25mil -187.25mil 8mil ]
    ElementLine [ -106.25mil -188.25mil -105.25mil -187.25mil 8mil ]
    ElementLine [  -86.25mil -188.25mil  -85.25mil -187.25mil 8mil ]
    ElementLine [  -66.25mil -188.25mil  -65.25mil -187.25mil 8mil ]
    ElementLine [  -46.25mil -188.25mil  -45.25mil -187.25mil 8mil ]
    ElementLine [  -26.25mil -188.25mil  -25.25mil -187.25mil 8mil ]
    ElementLine [   -6.25mil -188.25mil   -5.25mil -187.25mil 8mil ]
    ElementLine [   13.75mil -188.25mil   14.75mil -187.25mil 8mil ]
    ElementLine [   33.75mil -188.25mil   34.75mil -187.25mil 8mil ]
    ElementLine [   53.75mil -188.25mil   54.75mil -187.25mil 8mil ]
    ElementLine [   73.75mil -188.25mil   74.75mil -187.25mil 8mil ]
    # Bottom
    ElementLine [ -146.25mil  187.25mil -145.25mil  188.25mil 8mil ]
    ElementLine [ -126.25mil  187.25mil -125.25mil  188.25mil 8mil ]
    ElementLine [ -106.25mil  187.25mil -105.25mil  188.25mil 8mil ]
    ElementLine [  -86.25mil  187.25mil  -85.25mil  188.25mil 8mil ]
    ElementLine [  -66.25mil  187.25mil  -65.25mil  188.25mil 8mil ]
    ElementLine [  -46.25mil  187.25mil  -45.25mil  188.25mil 8mil ]
    ElementLine [  -26.25mil  187.25mil  -25.25mil  188.25mil 8mil ]
    ElementLine [   -6.25mil  187.25mil   -5.25mil  188.25mil 8mil ]
    ElementLine [   13.75mil  187.25mil   14.75mil  188.25mil 8mil ]
    ElementLine [   33.75mil  187.25mil   34.75mil  188.25mil 8mil ]
    ElementLine [   53.75mil  187.25mil   54.75mil  188.25mil 8mil ]
    ElementLine [   73.75mil  187.25mil   74.75mil  188.25mil 8mil ]
    # Left (top segment)
    ElementLine [ -146.25mil -188.25mil -145.25mil -187.25mil 8mil ]
    ElementLine [ -146.25mil -168.25mil -145.25mil -167.25mil 8mil ]
    ElementLine [ -146.25mil -148.25mil -145.25mil -147.25mil 8mil ]
    ElementLine [ -146.25mil -128.25mil -145.25mil -127.25mil 8mil ]
    ElementLine [ -146.25mil -108.25mil -145.25mil -107.25mil 8mil ]
    ElementLine [ -146.25mil  -88.25mil -145.25mil  -87.25mil 8mil ]
    # Left (bottom segment)
    ElementLine [ -146.25mil  187.25mil -145.25mil  188.25mil 8mil ]
    ElementLine [ -146.25mil  167.25mil -145.25mil  168.25mil 8mil ]
    ElementLine [ -146.25mil  147.25mil -145.25mil  148.25mil 8mil ]
    ElementLine [ -146.25mil  127.25mil -145.25mil  128.25mil 8mil ]
    ElementLine [ -146.25mil  107.25mil -145.25mil  108.25mil 8mil ]
    ElementLine [ -146.25mil   87.25mil -145.25mil   88.25mil 8mil ]
    # Right (top segment)
    ElementLine [   70.25mil -188.25mil   71.25mil -187.25mil 8mil ]
    ElementLine [   70.25mil -168.25mil   71.25mil -167.25mil 8mil ]
    ElementLine [   70.25mil -148.25mil   71.25mil -147.25mil 8mil ]
    ElementLine [   70.25mil -128.25mil   71.25mil -127.25mil 8mil ]
    ElementLine [   70.25mil -108.25mil   71.25mil -107.25mil 8mil ]
    ElementLine [   70.25mil  -88.25mil   71.25mil  -87.25mil 8mil ]
    # Right (bottom segment)
    ElementLine [   70.25mil  187.25mil   71.25mil  188.25mil 8mil ]
    ElementLine [   70.25mil  167.25mil   71.25mil  168.25mil 8mil ]
    ElementLine [   70.25mil  147.25mil   71.25mil  148.25mil 8mil ]
    ElementLine [   70.25mil  127.25mil   71.25mil  128.25mil 8mil ]
    ElementLine [   70.25mil  107.25mil   71.25mil  108.25mil 8mil ]
    ElementLine [   70.25mil   87.25mil   71.25mil   88.25mil 8mil ]
    # }}} END GENERATED CONTENT


    )
# vim: set et nosmarttab smartindent ts=4 sts=4 sw=4 fileencoding=utf-8:
